@@ -188,14 +188,15 @@ class APIClient(json.JSONEncoder):
 
         headers = {
             "Content-type": "application/x-www-form-urlencoded",
-            "Accept": "text/plain",
+            "Accept": "application/json",
         }
 
         resp = requests.post(
             self.access_token_url, data=urlencode(args), headers=headers
-        ).json()
+        )
+        results = _validate(resp).json()
 
-        self.access_token = resp["access_token"]
+        self.access_token = results["access_token"]
         return resp
 
     def token_for_code(self, code):
