@@ -180,6 +180,10 @@ def mock_accounts(mocked_responses, api_url, account_id, client_id):
             response["metadata"] = payload["metadata"]
         return 200, {}, json.dumps(response)
 
+    def delete_callback(request):
+        response = {"success": True}
+        return 200, {}, json.dumps(response)
+
     url_re = "{base}(/a/{client_id})?/accounts/?".format(
         base=api_url, client_id=client_id
     )
@@ -195,6 +199,12 @@ def mock_accounts(mocked_responses, api_url, account_id, client_id):
         content_type="application/json",
         callback=update_callback,
     )
+    mocked_responses.add_callback(
+        responses.DELETE,
+        re.compile(url_re),
+        content_type="application/json",
+        callback=delete_callback,
+    )
 
 
 @pytest.fixture
@@ -322,10 +332,18 @@ def mock_folder(mocked_responses, api_url, account_id):
             folder.update(payload)
         return (200, {}, json.dumps(folder))
 
+    def delete_callback(request):
+        payload = {"successful": True}
+        return 200, {}, json.dumps(payload)
+
     mocked_responses.add_callback(
         responses.PUT, url, content_type="application/json", callback=request_callback
     )
 
+    mocked_responses.add_callback(
+        responses.DELETE, url, content_type="application/json", callback=delete_callback
+    )
+
 
 @pytest.fixture
 def mock_messages(mocked_responses, api_url, account_id):
@@ -813,6 +831,13 @@ def mock_event_create_response(mocked_responses, api_url, message_body):
     )
 
 
+@pytest.fixture
+def mock_event_generate_ics(mocked_responses, api_url, message_body):
+    mocked_responses.add(
+        responses.POST, api_url + "/events/to-ics", body=json.dumps({"ics": ""})
+    )
+
+
 @pytest.fixture
 def mock_scheduler_create_response(mocked_responses, api_url, message_body):
     def callback(_request):
@@ -1175,6 +1200,7 @@ def mock_contact(mocked_responses, account_id, api_url):
         "job_title": "QA Tester",
         "manager_name": "George",
         "office_location": "Over the Rainbow",
+        "source": "inbox",
         "notes": "This is a note",
         "picture_url": "{base}/contacts/{id}/picture".format(
             base=api_url, id="9hga75n6mdvq4zgcmhcn7hpys"
@@ -1715,6 +1741,40 @@ def mock_revoke_all_tokens(mocked_responses, api_url, account_id, client_id):
     )
 
 
+@pytest.fixture
+def mock_application_details(mocked_responses, api_url, client_id):
+    application_details_url = "{base}/a/{client_id}".format(
+        base=api_url, client_id=client_id
+    )
+
+    def modify_endpoint(request):
+        return 200, {}, json.dumps(json.loads(request.body))
+
+    mocked_responses.add(
+        responses.GET,
+        application_details_url,
+        content_type="application/json",
+        status=200,
+        body=json.dumps(
+            {
+                "application_name": "My New App Name",
+                "icon_url": "http://localhost:5555/icon.png",
+                "redirect_uris": [
+                    "http://localhost:5555/login_callback",
+                    "localhost",
+                    "https://customerA.myapplication.com/login_callback",
+                ],
+            }
+        ),
+    )
+    mocked_responses.add_callback(
+        responses.PUT,
+        application_details_url,
+        content_type="application/json",
+        callback=modify_endpoint,
+    )
+
+
 @pytest.fixture
 def mock_ip_addresses(mocked_responses, api_url, client_id):
     ip_addresses_url = "{base}/a/{client_id}/ip_addresses".format(
